#mkFComponent w
#
# Create a top-level window for the Component 
#
# Arguments:
# w - Name to use for the new top-level window

set auto_path "$env(CLIBHOME)/Tcl_Tk $auto_path"

proc mkFComponent {fpath fname {w .component}} {
   global DPATH DNAME SELECT TYPE

   set DPATH [set fpath]
   set DNAME [set fname]
   catch {destroy $w}
   toplevel $w
   wm title $w "XCodelib"
   wm geometry $w 500x300 

   frame $w.menubar
   button $w.menubar.done -text "Done" -command "mkFDone $w $fname"
   button $w.menubar.print -text "Print" -command "mkPrint" 
   button $w.menubar.download -text "Download" \
	   -command "mkFDownload $w $fpath $fname"
   button $w.menubar.help -text "Help" -command "mkCHelp"
   pack $w.menubar.done $w.menubar.print $w.menubar.download -side left \
   -pady 5 -padx 5
   pack $w.menubar.help -side right -pady 5 -padx 10

   frame $w.title
   label $w.title.label -text "Component Title :" -width 15 -anchor w
   entry $w.title.entry -width 70 -relief sunken -bd 2 -state disabled
   pack $w.title.label $w.title.entry -side left

   frame $w.canvas -relief raised -bd 2 
   canvas $w.canvas.c -scrollregion {0c 0c 100c 30c} \
          -xscroll "$w.canvas.hscroll set" -yscroll "$w.canvas.vscroll set"
   scrollbar $w.canvas.vscroll -relief sunken -command "$w.canvas.c yview"
   scrollbar $w.canvas.hscroll -orient horiz -relief sunken -command "$w.canvas.c xview"
   pack $w.canvas.vscroll -side left -fill y
   pack $w.canvas.hscroll -side bottom  -fill x
   pack $w.canvas.c -expand yes -fill both

   frame $w.text -relief raised -bd 2
   text $w.text.t -yscrollcommand "$w.text.vscroll set" -setgrid true
   scrollbar $w.text.vscroll -relief sunken -command "$w.text.t yview"
   pack $w.text.vscroll -side left -fill y
   pack $w.text.t -expand yes -fill both

   frame $w.download -relief raised -bd 2

   frame $w.download.title
   label $w.download.title.label -text "Download Path :" -width 15 -anchor w
   entry $w.download.title.entry -width 70 -relief sunken -bd 2 \
         -textvariable downloadPath
   pack $w.download.title.label $w.download.title.entry -side left
   pack $w.download.title -side top -fill x

   frame $w.download.menubar 
   button $w.download.menubar.get -text "Get Files Now" \
           -command "mkFGetFiles $w \$downloadPath"
   button $w.download.menubar.unselect -text "Unselect all Files" \
          -command "FUnselectFiles $w"
   button $w.download.menubar.select -text "Select all Files" \
          -command "FSelectFiles $w" 
   button $w.download.menubar.return -text "Return" -command "mkFDownReturn $w"
   pack $w.download.menubar.get $w.download.menubar.unselect \
        $w.download.menubar.select -side left -pady 5 -padx 5
   pack $w.download.menubar.return -side right -pady 5 -padx 5
   pack $w.download.menubar -side top -fill x

   frame $w.download.display 
   frame $w.download.display.inner -geometry 20x30 -relief raised \
         -borderwidth 2 -bg SteelBlue1
   pack $w.download.display.inner -expand yes -anchor sw
   pack $w.download.display -side top -fill x 

   frame $w.download.canvas -relief raised -bd 2 
   canvas $w.download.canvas.c -scrollregion {0c 0c 100c 30c} \
          -yscroll "$w.download.canvas.vscroll set"
   scrollbar $w.download.canvas.vscroll -relief sunken \
             -command "$w.download.canvas.c yview"
   pack $w.download.canvas.vscroll -side left -fill y
   pack $w.download.canvas.c -expand yes -fill both
   pack $w.download.canvas -side top -fill x
   
   $w.title.entry configure -state normal
   $w.title.entry delete 0 end
   $w.title.entry insert 0 $fname
   $w.title.entry configure -state disabled 

   pack $w.menubar -side top -fill x
   pack $w.title -side top -fill x
   pack $w.text -side top -fill x
   update idletasks
   grab $w
   switch $TYPE {
	Local	{
   			set SELECT [concat $SELECT $fpath/$fname]
			TextLoadFile $w.text.t $fpath/$fname
		}
	Remote  {
   			set SELECT [concat $SELECT $fname]
			set last [string last / $fname]
			set file [string range $fname [expr $last+1] end]
			TextLoadFile $w.text.t $file
		}
   }
}

proc mkPrint {} {
	puts stdout "Print"
}

proc mkCHelp {} {
	puts stdout "Help"
}

proc mkFDone {w fname} {
	global SELECT TYPE

	set SELECT [list ]
	if { $TYPE == "Remote"} {
		set last [string last / $fname]
		set file [string range $fname [expr $last+1] end]
		if [file exists $file] {
			exec rm $file
		}
	}
	destroy $w
}

#mkFComponent
 
