#mkSearch w
#
# Create a top-level window for the Search procedure
#
# Arguments:
# w - Name to use for the new top-level window

set auto_path "$env(CLIBHOME)/Tcl_Tk $auto_path"

proc mkSearch {{w .search}} {
   catch {destroy $w}
   toplevel $w
   grab $w
   wm title $w "XCodelib"
   wm geometry $w 500x650 
   frame $w.menubar
   button $w.menubar.done -text "Done" -command "destroy $w"
   button $w.menubar.help -text "Help" -command "mkSHelp"
   pack $w.menubar.done -side left -pady 5 -padx 5
   pack $w.menubar.help -side right -pady 5 -padx 10

   frame $w.type
   label $w.type.label -text "Search Type :" -width 13 -anchor w
   button $w.type.and -text "And" -command "AndSearch"
   button $w.type.or -text "Or" -command "OrSearch"
   button $w.type.literal -text "Literal" -command "LiteralSearch"
   button $w.type.similar -text "Similar" -command "SimilarSearch $w"
   scale $w.type.scale -orient horizontal -length 50 -from 0 -to 50\
   -width 15 -showvalue 0 -sliderlength 10 -command "UpdateValue $w"
   set font1 -Adobe-Courier-Bold-R-Normal-*-120-* 
   entry $w.type.entry -width 8 -relief sunken -bd 2 -font $font1  
   $w.type.entry insert 0 "HITS:"

   pack $w.type.label -side left 
   pack $w.type.and $w.type.or $w.type.literal $w.type.similar \
   $w.type.scale $w.type.entry -side left -padx 10 -pady 5

   frame $w.string
   label $w.string.label -text "Search String :" -width 13 -anchor w 
   entry $w.string.entry -width 40 -relief sunken -bd 2 \
	-textvariable searchString
   pack $w.string.label $w.string.entry -side left
   bind $w.string.entry <Return> "mkGo $w \$searchString" 
   button $w.string.abort -text "Clear" -command "mkClear $w"
   button $w.string.go -text "Go" -command "mkGo $w \$searchString"
   pack $w.string.go $w.string.abort -side left -pady 5 -padx 10

   frame $w.components -relief raised -bd 2
   canvas $w.components.c -height 200 -scrollregion {0c 0c 0c 30c} \
	-yscroll "$w.components.vscroll set"
   scrollbar $w.components.vscroll -relief sunken \
             -command "$w.components.c yview"
   pack $w.components.vscroll -side left -fill y
   pack $w.components.c -expand yes -fill both

   frame $w.status
   label $w.status.label -text "Status :" -width 7 -anchor w
   entry $w.status.entry -width 50 -relief sunken -bd 2 -state disabled
   pack $w.status.label $w.status.entry -side left

   frame $w.queryb
   button $w.queryb.b1 -text "Last Query Results" -command "LastQuery $w"
   button $w.queryb.b2 -text "Union" -command "mkUnion $w"
   button $w.queryb.b3 -text "Intersection" -command "mkIntersection $w"
   pack $w.queryb.b1 -side left -pady 5 -padx 5
   pack $w.queryb.b2 $w.queryb.b3  -side right -pady 5 -padx 10

   frame $w.queryc -relief raised -bd 2
   canvas $w.queryc.c -height 150 -scrollregion {0c 0c 0c 30c} \
       -yscroll "$w.queryc.vscroll set"
   scrollbar $w.queryc.vscroll -relief sunken -command "$w.queryc.c yview"
   pack $w.queryc.vscroll -side left -fill y
   pack $w.queryc.c -expand yes -fill both 

   frame $w.similarb
   label $w.similarb.label -text "Similar to :" -width 13 -anchor w 
   button $w.similarb.b3 -text "Delete All" -command "SimilarDeleteAll $w"
   pack $w.similarb.label -side left
   pack $w.similarb.b3 -side left -padx 10 -pady 5
   
   frame $w.similarc -relief raised -bd 2
   canvas $w.similarc.c -height 100 -scrollregion {0c 0c 0c 30c} \
          -yscroll "$w.similarc.vscroll set"
   scrollbar $w.similarc.vscroll -relief sunken -command "$w.similarc.c yview"
   pack $w.similarc.vscroll -side left -fill y
   pack $w.similarc.c -expand yes -fill both

   pack $w.menubar -side top -fill x
   pack $w.type -side top -fill x
   pack $w.string -side top -fill x
   pack $w.components -side top -fill x
   pack $w.status -side top -fill x
   pack $w.queryb -side top -fill x
   pack $w.queryc -side top -fill x
   pack $w.similarb -side top -fill x
   pack $w.similarc -side top -fill x
}

proc UpdateValue {w value} {
   	global MAXHITS
	set MAXHITS $value
	$w.type.entry delete 0 end
	$w.type.entry insert 0 "HITS: $value"
}

proc mkSHelp {} {
	puts stdout "Help"
}

proc mkClear {w} {
	global SCY SCNo SIMILARLIST COMPLIST LASTQUERY

	$w.components.c delete all
	$w.similarc.c delete all
	$w.queryc.c delete all
	$w.string.entry delete 0 end
	$w.status.entry configure -state normal
	$w.status.entry delete 0 end
	$w.status.entry configure -state disabled
	set SCY 10; set SCNo 0
	set SIMILARLIST [list ]
	set LASTQUERY $COMPLIST
}


proc OrSearch {} {
	global SearchType
	set SearchType Or
}

proc AndSearch {} {
	global SearchType
	set SearchType And
}

proc LiteralSearch {} {
	global SearchType
	set SearchType Literal
}

proc SimilarSearch {w} {
	global SearchType
	set SearchType Similar
	$w.components.c delete all
	$w.string.entry delete 0 end
	$w.status.entry configure -state normal
	$w.status.entry delete 0 end
	$w.status.entry configure -state disabled
}

proc LastQuery {w} {
	global LASTQUERY HOME

	$w.queryc.c delete all
	set c $w.queryc.c
	set font1 -Adobe-Courier-Bold-R-Normal-*-120-*
	set ComponentList $LASTQUERY
	set ListLength [llength $ComponentList]
        set l 0
        set x 10; set y 10
        while {$l < $ListLength} {
             set El(0) [lindex $ComponentList $l]
             incr l
             set El(1) [lindex $ComponentList $l]
             if [string match */ $El(1)] {
                      $c create bitmap $x $y \
			-bitmap @$HOME/Tcl_Tk/Bitmaps/component.bit
                      $c create text [expr $x+25] $y -justify left\
			 -anchor w -text $El(0) -font $font1 
              } else {
                      $c create bitmap $x $y \
			-bitmap @$HOME/Tcl_Tk/Bitmaps/file.bit 
                      $c create text [expr $x+25] $y -justify left\
			 -anchor w -text $El(0) -font $font1 
              }
              incr y 20; incr l
      }
}

proc mkUnion {w} {
	global SearchType
	set SearchType Union
}

proc mkIntersection {w} {
	global SearchType
	set SearchType Intersection
}

proc SimilarDeleteAll {w} {
	global SCY SCNo SIMILARLIST

	$w.similarc.c delete all
	set SCY 10 
	set SCNo 0
	set SIMILARLIST [list ]
}

