#include <stdio.h>
#include <thread.h>
#include <synch.h>

extern char *shmalloc( /* unsigned size */ );
extern shfree( /* char *ptr */ );

#include <usclkc.h>

typedef double real;
typedef double *Vector;
typedef Vector *Matrix;

static shared Vector b;
static shared Matrix a;
static shared int n;     /* system size */
static shared int blk;   /* size of a blk */

static shared usclk_t DefTime;  /* this is evil but is only for timing */
static shared usclk_t EndTime;

void readsize(printp)
  int *printp;
{
  int numblks;

  usclk_init();

  printf("Enter the size of the block system: ");
  scanf("%d", &numblks);

  printf("Enter the size of a block (integer): ");
  scanf("%d", &blk);
  n = numblks*blk;

  printf("Print all (0 or 1): ");
  scanf("%d", printp);
}

  /* Allocate space for b */

Vector MakeB()
{
   return (Vector) shmalloc(n*sizeof(real));
}

  /* Allocate space for A */

Matrix MakeA()
{
   Matrix t;
   int i;

   t = (Matrix) shmalloc(n*sizeof(Vector));

   for (i = 0; i < n; i++)
      t[i] = (Vector) shmalloc((i+1)*sizeof(real));

   return t;
}

  /* Allocare and obtain values for a and b */

void readsys()
{
   int i, j;
   Vector tmp;

   for (i = 0; i < n; i++) {
      b[i] = i + 1.0;
      tmp = a[i];
      for (j = 0; j <= i; j++)
        tmp[j] = 1.0;
   }
   DefTime = getusclk();
}


  /* initialize number of blocks and count of blocks solved */

void setnumblks(nb)
  int *nb;
{
   int i = n % blk;

   if (i == 0)
     *nb = n / blk;
   else
     *nb = (n/blk) + 1;
}


  /* Solve a block wb */

void solveblock(wb)
  int wb;
{
  int init = wb * blk;
  int final = init + blk;
  double sum;
  Vector tmp;
  int i, j;

  if (final > n)
    final = n;

  for (i = init; i < final; i++) {
     sum = b[i];
     tmp = a[i];
     for (j = init; j < i; j++)
       sum = sum - tmp[j]*b[j];
     b[i] = sum / tmp[i];
  }
}


   /* Do matrix vector multiply for a block brow, bcol */

void blkmult(brow, bcol)
   int brow;
   int bcol;
{
   int init_row = brow * blk;
   int end_row = init_row + blk;
   int init_col = bcol * blk;
   int end_col = init_col + blk;
   int init = brow * blk;
   double sum;
   Vector tmp;
   int i, j;

   if (end_row > n)
     end_row = n;

   for (i = init_row; i < end_row; i++) {
      sum = b[i];
      tmp = a[i];
      for (j = init_col; j < end_col; j++)
        sum = sum - tmp[j]*b[j];
      b[i] = sum;
   }
}


   /* print b */

void printans(printp)
   int printp;
{
   int start, stop;
   int i;

   if (printp == 0) {
      start = n/2;
      stop = start;
   } else {
      start = 0;
      stop = n - 1;
   }

   for (i = start; i <= stop; i++)
     printf("x[%d] = %f\n", i, b[i]);

   EndTime = getusclk();
   printf("Parallel part = %u\n", EndTime - DefTime);
}


shared Thread *proc[32];   /* Note this has to be shared.  Could put it */
                           /*   on stack in main */


Main ()    /* Note it's Main not main */
{
   int printp;
   int BlocksToSolve;
   int i, j;

   readsize(&printp);         /* asserts that blk divides n, but alg */
                              /* does not require this */
   a = MakeA();
   b = MakeB();

   readsys();

   setnumblks(&BlocksToSolve);

   for (i = 0; i < BlocksToSolve; i++) {
      solveblock(i);
      for (j = i + 1; j < BlocksToSolve; j++)
	proc[j] = ThreadStart(blkmult, 1, "blkmult", 2*sizeof(int), j, i);
      for (j = i + 1; j < BlocksToSolve; j++)
	ThreadJoin(proc[j]);
   }

   printans(printp);
   printf("Program done.\n");
   ProgramDone();     /* Do not forget this! */
}
